@@ -1,6 +1,7 @@
 """
 Form Widget classes specific to the Django admin site.
 """
+
 import copy
 import json
 
@@ -9,6 +10,7 @@ from django.conf import settings
 from django.core.exceptions import ValidationError
 from django.core.validators import URLValidator
 from django.db.models import CASCADE, UUIDField
+from django.forms.widgets import Select
 from django.urls import reverse
 from django.urls.exceptions import NoReverseMatch
 from django.utils.html import smart_urlquote
@@ -48,7 +50,16 @@ class FilteredSelectMultiple(forms.SelectMultiple):
         return context
 
 
-class BaseAdminDateWidget(forms.DateInput):
+class DateTimeWidgetContextMixin:
+    def get_context(self, name, value, attrs):
+        context = super().get_context(name, value, attrs)
+        context["widget"]["attrs"][
+            "aria-describedby"
+        ] = f"id_{name}_timezone_warning_helptext"
+        return context
+
+
+class BaseAdminDateWidget(DateTimeWidgetContextMixin, forms.DateInput):
     class Media:
         js = [
             "admin/js/calendar.js",
@@ -64,7 +75,7 @@ class AdminDateWidget(BaseAdminDateWidget):
     template_name = "admin/widgets/date.html"
 
 
-class BaseAdminTimeWidget(forms.TimeInput):
+class BaseAdminTimeWidget(DateTimeWidgetContextMixin, forms.TimeInput):
     class Media:
         js = [
             "admin/js/calendar.js",
@@ -97,8 +108,13 @@ class AdminSplitDateTime(forms.SplitDateTimeWidget):
         context = super().get_context(name, value, attrs)
         context["date_label"] = _("Date:")
         context["time_label"] = _("Time:")
+        for widget in context["widget"]["subwidgets"]:
+            widget["attrs"]["aria-describedby"] = f"id_{name}_timezone_warning_helptext"
         return context
 
+    def id_for_label(self, id_):
+        return id_
+
 
 class AdminRadioSelect(forms.RadioSelect):
     template_name = "admin/widgets/radio.html"
@@ -106,6 +122,7 @@ class AdminRadioSelect(forms.RadioSelect):
 
 class AdminFileWidget(forms.ClearableFileInput):
     template_name = "admin/widgets/clearable_file_input.html"
+    use_fieldset = True
 
 
 def url_params_from_lookup_dict(lookups):
@@ -145,7 +162,7 @@ class ForeignKeyRawIdWidget(forms.TextInput):
     def get_context(self, name, value, attrs):
         context = super().get_context(name, value, attrs)
         rel_to = self.rel.model
-        if rel_to in self.admin_site._registry:
+        if self.admin_site.is_registered(rel_to):
             # The related object is registered with the same AdminSite
             related_url = reverse(
                 "admin:%s_%s_changelist"
@@ -202,7 +219,7 @@ class ForeignKeyRawIdWidget(forms.TextInput):
                 % (
                     self.admin_site.name,
                     obj._meta.app_label,
-                    obj._meta.object_name.lower(),
+                    obj._meta.model_name,
                 ),
                 args=(obj.pk,),
             )
@@ -214,15 +231,15 @@ class ForeignKeyRawIdWidget(forms.TextInput):
 
 class ManyToManyRawIdWidget(ForeignKeyRawIdWidget):
     """
-    A Widget for displaying ManyToMany ids in the "raw_id" interface rather than
-    in a <select multiple> box.
+    A Widget for displaying ManyToMany ids in the "raw_id" interface rather
+    than in a <select multiple> box.
     """
 
     template_name = "admin/widgets/many_to_many_raw_id.html"
 
     def get_context(self, name, value, attrs):
         context = super().get_context(name, value, attrs)
-        if self.rel.model in self.admin_site._registry:
+        if self.admin_site.is_registered(self.rel.model):
             # The related object is registered with the same AdminSite
             context["widget"]["attrs"]["class"] = "vManyToManyRawIdAdminField"
         return context
@@ -262,23 +279,28 @@ class RelatedFieldWidgetWrapper(forms.Widget):
     ):
         self.needs_multipart_form = widget.needs_multipart_form
         self.attrs = widget.attrs
-        self.choices = widget.choices
         self.widget = widget
         self.rel = rel
         # Backwards compatible check for whether a user can add related
         # objects.
         if can_add_related is None:
-            can_add_related = rel.model in admin_site._registry
+            can_add_related = admin_site.is_registered(rel.model)
         self.can_add_related = can_add_related
-        # XXX: The UX does not support multiple selected values.
-        multiple = getattr(widget, "allow_multiple_selected", False)
-        self.can_change_related = not multiple and can_change_related
-        # XXX: The deletion UX can be confusing when dealing with cascading deletion.
+        if not isinstance(widget, AutocompleteMixin):
+            self.attrs["data-context"] = "available-source"
+        # Only single-select Select widgets are supported.
+        supported = not getattr(
+            widget, "allow_multiple_selected", False
+        ) and isinstance(widget, Select)
+        self.can_change_related = supported and can_change_related
+        # XXX: The deletion UX can be confusing when dealing with cascading
+        # deletion.
         cascade = getattr(rel, "on_delete", None) is CASCADE
-        self.can_delete_related = not multiple and not cascade and can_delete_related
-        self.can_view_related = not multiple and can_view_related
-        # so we can check if the related object is registered with this AdminSite
+        self.can_delete_related = supported and not cascade and can_delete_related
+        self.can_view_related = supported and can_view_related
+        # To check if the related object is registered with this AdminSite.
         self.admin_site = admin_site
+        self.use_fieldset = True
 
     def __deepcopy__(self, memo):
         obj = copy.copy(self)
@@ -295,9 +317,17 @@ class RelatedFieldWidgetWrapper(forms.Widget):
     def media(self):
         return self.widget.media
 
+    @property
+    def choices(self):
+        return self.widget.choices
+
+    @choices.setter
+    def choices(self, value):
+        self.widget.choices = value
+
     def get_related_url(self, info, action, *args):
         return reverse(
-            "admin:%s_%s_%s" % (info + (action,)),
+            "admin:%s_%s_%s" % (*info, action),
             current_app=self.admin_site.name,
             args=args,
         )
@@ -307,7 +337,6 @@ class RelatedFieldWidgetWrapper(forms.Widget):
 
         rel_opts = self.rel.model._meta
         info = (rel_opts.app_label, rel_opts.model_name)
-        self.widget.choices = self.choices
         related_field_name = self.rel.get_related_field().name
         url_params = "&".join(
             "%s=%s" % param
@@ -322,6 +351,7 @@ class RelatedFieldWidgetWrapper(forms.Widget):
             "name": name,
             "url_params": url_params,
             "model": rel_opts.verbose_name,
+            "model_name": rel_opts.model_name,
             "can_add_related": self.can_add_related,
             "can_change_related": self.can_change_related,
             "can_delete_related": self.can_delete_related,
@@ -572,9 +602,7 @@ class AutocompleteMixin:
             js=(
                 "admin/js/vendor/jquery/jquery%s.js" % extra,
                 "admin/js/vendor/select2/select2.full%s.js" % extra,
-            )
-            + i18n_file
-            + (
+                *i18n_file,
                 "admin/js/jquery.init.js",
                 "admin/js/autocomplete.js",
             ),
