@@ -100,7 +100,7 @@ def get_token(request):
 
     A side effect of calling this function is to make the csrf_protect
     decorator and the CsrfViewMiddleware add a CSRF cookie and a 'Vary: Cookie'
-    header to the outgoing response.  For this reason, you may need to use this
+    header to the outgoing response. For this reason, you may need to use this
     function lazily, as is done by the csrf context processor.
     """
     if "CSRF_COOKIE" in request.META:
@@ -201,7 +201,7 @@ class CsrfViewMiddleware(MiddlewareMixin):
     # requires_csrf_token decorator.
     def _accept(self, request):
         # Avoid checking the request twice by adding a custom attribute to
-        # request.  This will be relevant when both decorator and middleware
+        # request. This will be relevant when both decorator and middleware
         # are used.
         request.csrf_processing_done = True
         return None
@@ -287,11 +287,11 @@ class CsrfViewMiddleware(MiddlewareMixin):
             parsed_origin = urlsplit(request_origin)
         except ValueError:
             return False
-        request_scheme = parsed_origin.scheme
-        request_netloc = parsed_origin.netloc
+        parsed_origin_scheme = parsed_origin.scheme
+        parsed_origin_netloc = parsed_origin.netloc
         return any(
-            is_same_domain(request_netloc, host)
-            for host in self.allowed_origin_subdomains.get(request_scheme, ())
+            is_same_domain(parsed_origin_netloc, host)
+            for host in self.allowed_origin_subdomains.get(parsed_origin_scheme, ())
         )
 
     def _check_referer(self, request):
@@ -420,7 +420,8 @@ class CsrfViewMiddleware(MiddlewareMixin):
         if getattr(callback, "csrf_exempt", False):
             return None
 
-        # Assume that anything not defined as 'safe' by RFC 9110 needs protection
+        # Assume that anything not defined as 'safe' by RFC 9110 needs
+        # protection
         if request.method in ("GET", "HEAD", "OPTIONS", "TRACE"):
             return self._accept(request)
 
