@@ -9,6 +9,7 @@ from ..fields import (
     EnumField,
     HStoreField,
     IntegerRangeField,
+    OffByOneField,
     SearchVectorField,
 )
 from ..models import TagField
@@ -25,14 +26,14 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
                         primary_key=True,
                     ),
                 ),
-                ("field", ArrayField(models.CharField(max_length=10), size=None)),
+                ("field", ArrayField(models.CharField(max_length=10))),
             ],
             options={
                 "required_db_vendor": "postgresql",
@@ -44,16 +45,16 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
                         primary_key=True,
                     ),
                 ),
-                ("datetimes", ArrayField(models.DateTimeField(), size=None)),
-                ("dates", ArrayField(models.DateField(), size=None)),
-                ("times", ArrayField(models.TimeField(), size=None)),
+                ("datetimes", ArrayField(models.DateTimeField())),
+                ("dates", ArrayField(models.DateField())),
+                ("times", ArrayField(models.TimeField())),
             ],
             options={
                 "required_db_vendor": "postgresql",
@@ -65,7 +66,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -85,7 +86,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -94,21 +95,20 @@ class Migration(migrations.Migration):
                 ),
                 (
                     "ips",
-                    ArrayField(models.GenericIPAddressField(), size=None, default=list),
+                    ArrayField(models.GenericIPAddressField(), default=list),
                 ),
-                ("uuids", ArrayField(models.UUIDField(), size=None, default=list)),
+                ("uuids", ArrayField(models.UUIDField(), default=list)),
                 (
                     "decimals",
                     ArrayField(
                         models.DecimalField(max_digits=5, decimal_places=2),
-                        size=None,
                         default=list,
                     ),
                 ),
-                ("tags", ArrayField(TagField(), blank=True, null=True, size=None)),
+                ("tags", ArrayField(TagField(), blank=True, null=True)),
                 (
                     "json",
-                    ArrayField(models.JSONField(default=dict), default=list, size=None),
+                    ArrayField(models.JSONField(default=dict), default=list),
                 ),
                 ("int_ranges", ArrayField(IntegerRangeField(), null=True, blank=True)),
                 (
@@ -126,7 +126,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -135,9 +135,7 @@ class Migration(migrations.Migration):
                 ),
                 (
                     "field",
-                    ArrayField(
-                        models.IntegerField(), blank=True, default=list, size=None
-                    ),
+                    ArrayField(models.BigIntegerField(), blank=True, default=list),
                 ),
             ],
             options={
@@ -150,7 +148,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -159,7 +157,7 @@ class Migration(migrations.Migration):
                 ),
                 (
                     "field",
-                    ArrayField(ArrayField(models.IntegerField(), size=None), size=None),
+                    ArrayField(ArrayField(models.IntegerField())),
                 ),
             ],
             options={
@@ -172,7 +170,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -194,7 +192,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -203,14 +201,12 @@ class Migration(migrations.Migration):
                 ),
                 (
                     "field",
-                    ArrayField(models.IntegerField(), size=None, null=True, blank=True),
+                    ArrayField(models.BigIntegerField(), null=True, blank=True),
                 ),
                 (
                     "field_nested",
                     ArrayField(
-                        ArrayField(models.IntegerField(null=True), size=None),
-                        size=None,
-                        null=True,
+                        ArrayField(models.BigIntegerField(null=True)), null=True
                     ),
                 ),
                 ("order", models.IntegerField(null=True)),
@@ -225,7 +221,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -242,7 +238,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -279,7 +275,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -297,7 +293,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -314,7 +310,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -348,7 +344,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -370,7 +366,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -392,7 +388,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -419,7 +415,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -434,7 +430,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -449,7 +445,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -476,7 +472,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -515,7 +511,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -524,7 +520,7 @@ class Migration(migrations.Migration):
                 ),
                 (
                     "array_of_enums",
-                    ArrayField(EnumField(max_length=20), size=None),
+                    ArrayField(EnumField(max_length=20)),
                 ),
             ],
             options={
@@ -537,7 +533,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -552,7 +548,7 @@ class Migration(migrations.Migration):
             fields=[
                 (
                     "id",
-                    models.AutoField(
+                    models.BigAutoField(
                         verbose_name="ID",
                         serialize=False,
                         auto_created=True,
@@ -570,4 +566,26 @@ class Migration(migrations.Migration):
                 "required_db_vendor": "postgresql",
             },
         ),
+        migrations.CreateModel(
+            name="OffByOneModel",
+            fields=[
+                (
+                    "id",
+                    models.BigAutoField(
+                        verbose_name="ID",
+                        serialize=False,
+                        auto_created=True,
+                        primary_key=True,
+                    ),
+                ),
+                (
+                    "one_off",
+                    OffByOneField(),
+                ),
+            ],
+            options={
+                "required_db_vendor": "postgresql",
+            },
+            bases=(models.Model,),
+        ),
     ]
