@@ -1,5 +1,6 @@
 import os
 import sys
+import unittest
 from argparse import ArgumentDefaultsHelpFormatter
 from io import BytesIO, StringIO, TextIOWrapper
 from pathlib import Path
@@ -24,6 +25,7 @@ from django.db import connection
 from django.test import SimpleTestCase, override_settings
 from django.test.utils import captured_stderr, extend_sys_path
 from django.utils import translation
+from django.utils.version import PY314
 
 from .management.commands import dance
 from .utils import AssertFormatterFailureCaughtContext
@@ -454,6 +456,34 @@ class CommandTests(SimpleTestCase):
         self.assertIn("Working...", out.getvalue())
         self.assertIs(mocked_flush.called, True)
 
+    @unittest.skipUnless(PY314, "Only relevant for Python 3.14+")
+    def test_color_enabled_by_default(self):
+        with mock.patch.dict(os.environ, {}, clear=True):
+            command = BaseCommand()
+            parser = command.create_parser("prog_name", "subcommand")
+            self.assertTrue(parser.color)
+
+    @unittest.skipUnless(PY314, "Only relevant for Python 3.14+")
+    def test_color_disabled_with_django_colors_nocolor(self):
+        with mock.patch.dict(os.environ, {"DJANGO_COLORS": "nocolor"}):
+            command = BaseCommand()
+            parser = command.create_parser("prog_name", "subcommand")
+            self.assertFalse(parser.color)
+
+    @unittest.skipUnless(PY314, "Only relevant for Python 3.14+")
+    def test_force_color_does_not_affect_argparse_color(self):
+        with mock.patch.dict(os.environ, {}, clear=True):
+            command = BaseCommand(force_color=True)
+            parser = command.create_parser("prog_name", "subcommand")
+            self.assertTrue(parser.color)
+
+    @unittest.skipUnless(PY314, "Only relevant for Python 3.14+")
+    def test_no_color_flag_disables_color(self):
+        with mock.patch.object(sys, "argv", ["manage.py", "mycommand", "--no-color"]):
+            command = BaseCommand()
+            parser = command.create_parser("manage.py", "mycommand")
+            self.assertFalse(parser.color)
+
 
 class CommandRunTests(AdminScriptTestCase):
     """
@@ -488,8 +518,8 @@ class CommandRunTests(AdminScriptTestCase):
             "settings.py",
             apps=["django.contrib.staticfiles", "user_commands"],
             sdict={
-                # (staticfiles.E001) The STATICFILES_DIRS setting is not a tuple or
-                # list.
+                # (staticfiles.E001) The STATICFILES_DIRS setting is not a
+                # tuple or list.
                 "STATICFILES_DIRS": '"foo"',
             },
         )
@@ -565,11 +595,15 @@ class UtilsTests(SimpleTestCase):
         self.assertEqual(normalize_path_patterns(["foo/bar/*", "bar/*/"]), expected)
 
     def test_run_formatters_handles_oserror_for_black_path(self):
+        test_files_path = Path(__file__).parent / "test_files"
         cases = [
-            (FileNotFoundError, "nonexistent"),
+            (
+                FileNotFoundError,
+                str(test_files_path / "nonexistent"),
+            ),
             (
                 OSError if sys.platform == "win32" else PermissionError,
-                str(Path(__file__).parent / "test_files" / "black"),
+                str(test_files_path / "black"),
             ),
         ]
         for exception, location in cases:
